==> nextcloud-14.0.1.tgz: nextcloud/apps/files/l10n/fi.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Storage invalid" : "Virheellinen tallennustila",
    "Unknown error" : "Tuntematon virhe",
    "All files" : "Kaikki tiedostot",
    "Recent" : "Viimeaikaiset",
    "Favorites" : "Suosikit",
    "File could not be found" : "Tiedostoa ei löytynyt",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "Home" : "Koti",
    "Close" : "Sulje",
    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
    "Upload cancelled." : "Lähetys peruttu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
    "Uploading …" : "Lähetetään…",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
    "Actions" : "Toiminnot",
    "Rename" : "Nimeä uudelleen",
    "Copy" : "Kopioi",
    "Target folder" : "Kohdekansio",
    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
    "Unshare" : "Peru jakaminen",
    "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
    "Files" : "Tiedostot",
    "Details" : "Tiedot",
    "Select" : "Valitse",
    "Pending" : "Odottaa",
    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
    "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
    "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
    "New" : "Uusi",
    "{used} of {quota} used" : "{used}/{quota} käytetty",
    "{used} used" : "{used} käytetty",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole sallittu tiedostomuoto",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tallennustila on melkein loppu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastaa '{filter}'","vastaa '{filter}'"],
    "View in folder" : "Näe kansiossa",
    "Copied!" : "Kopioitu!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
    "Path" : "Polku",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Favorited" : "Lisätty suosikkeihin",
    "Favorite" : "Suosikki",
    "New folder" : "Uusi kansio",
    "Upload file" : "Lähetä tiedosto",
    "Not favorited" : "Ei suosikeissa",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
    "Added to favorites" : "Lisätty suosikkeihin",
    "Removed from favorites" : "Poistettu suosikeista",
    "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
    "You removed {file} from your favorites" : "Poistit tiedoston {file} suosikeista",
    "File changes" : "Tiedostomuutokset",
    "Created by {user}" : "Tekijänä {user}",
    "Changed by {user}" : "Muokkaajana {user}",
    "Deleted by {user}" : "Poistanut {user}",
    "Restored by {user}" : "Palauttanut {user}",
    "Renamed by {user}" : "Uudelleennimennyt {user}",
    "Moved by {user}" : "Siirtänyt {user}",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "You created {file}" : "Loit tiedoston {file}",
    "{user} created {file}" : "{user} loi tiedoston {file}",
    "{file} was created in a public folder" : "Tiedosto {file} luotiin julkisessa kansiossa",
    "You changed {file}" : "Muutit tiedostoa {file}",
    "{user} changed {file}" : "{user} muutti tiedostoa {file}",
    "You deleted {file}" : "Poistit tiedoston {file}",
    "{user} deleted {file}" : "{user} poisti tiedoston {file}",
    "You restored {file}" : "Palautit tiedoston {file}",
    "{user} restored {file}" : "{user} palautti tiedoston {file}",
    "You renamed {oldfile} to {newfile}" : "Uudelleennimesit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile}",
    "You moved {oldfile} to {newfile}" : "Siirsit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} siirsi tiedoston {oldfile} tiedostoksi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong> tai se on <strong>uudelleennimetty</strong>",
    "A new file or folder has been <strong>created</strong>" : "Uusi tiedosto tai kansio on <strong>luotu</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Tiedosto tai kansio on <strong>poistettu</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Rajoita luomis- ja muutosilmoitukset <strong>omiin suosikkitiedostoihin</strong> <em>(Vain listaus)</em>",
    "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
    "Unlimited" : "Rajoittamaton",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "File handling" : "Tiedostonhallinta",
    "Maximum upload size" : "Lähetettävän tiedoston suurin sallittu koko",
    "max. possible: " : "suurin mahdollinen:",
    "Save" : "Tallenna",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM:tä käyttäen muutoksien voimaantulossa saattaa kestää 5 minuuttia.",
    "Missing permissions to edit from here." : "Käyttöoikeudet eivät riitä tätä kautta muokkaamiseen.",
    "%s of %s used" : "%s / %s käytetty",
    "%s used" : "%s käytetty",
    "Settings" : "Asetukset",
    "Show hidden files" : "Näytä piilotetut tiedostot",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Käytä tätä osoitetta <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">käyttääksesi tiedostojasi WebDAV:in kautta</a>",
    "Cancel upload" : "Perus lähetys",
    "No files in here" : "Täällä ei ole tiedostoja",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Select all" : "Valitse kaikki",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "No favorites yet" : "Ei vielä suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
    "Tags" : "Tunnisteet",
    "Deleted files" : "Poistetut tiedostot",
    "Shared with others" : "Jaettu muille",
    "Shared with you" : "Jaettu kanssasi",
    "Shared by link" : "Jaettu linkillä",
    "Text file" : "Tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "Move" : "Siirrä",
    "A new file or folder has been <strong>deleted</strong>" : "Uusi tiedosto tai kansio on <strong>poistettu</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Uusi tiedosto tai kansio on <strong>palautettu</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Käytä tätä osoitetetta <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">käyttääksesi tiedostojasi WebDAV:in välityksellä</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/files/l10n/fi.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Storage invalid" : "Virheellinen tallennustila",
    "Unknown error" : "Tuntematon virhe",
    "All files" : "Kaikki tiedostot",
    "Recent" : "Viimeaikaiset",
    "Favorites" : "Suosikit",
    "File could not be found" : "Tiedostoa ei löytynyt",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "Home" : "Koti",
    "Close" : "Sulje",
    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
    "Upload cancelled." : "Lähetys peruttu.",
    "Processing files …" : "Käsitellään tiedostoja…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
    "An unknown error has occurred" : "Tapahtui tuntematon virhe",
    "Uploading …" : "Lähetetään…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
    "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
    "Actions" : "Toiminnot",
    "Rename" : "Nimeä uudelleen",
    "Copy" : "Kopioi",
    "Choose target folder" : "Valitse kohdekansio",
    "Open" : "Avaa",
    "Delete file" : "Poista tiedosto",
    "Delete folder" : "Poista kansio",
    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
    "Unshare" : "Peru jakaminen",
    "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
    "Files" : "Tiedostot",
    "Details" : "Tiedot",
    "Select" : "Valitse",
    "Pending" : "Odottaa",
    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
    "copy" : "kopio",
    "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
    "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
    "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
    "Could not fetch file details \"{file}\"" : "Ei voitu hakea tiedoston tietoja \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
    "New" : "Uusi",
    "Select file range" : "Valitse tiedostojoukko",
    "{used} of {quota} used" : "{used}/{quota} käytetty",
    "{used} used" : "{used} käytetty",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole sallittu tiedostomuoto",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tallennustila on melkein loppu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastaa '{filter}'","vastaa '{filter}'"],
    "View in folder" : "Näe kansiossa",
    "Copied!" : "Kopioitu!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
    "Path" : "Polku",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Favorited" : "Lisätty suosikkeihin",
    "Favorite" : "Suosikki",
    "You can only favorite a single file or folder at a time" : "Voit valita suosikiksi vain yhden tiedoston tai kansion kerrallaan",
    "New folder" : "Uusi kansio",
    "Upload file" : "Lähetä tiedosto",
    "Not favorited" : "Ei suosikeissa",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
    "Added to favorites" : "Lisätty suosikkeihin",
    "Removed from favorites" : "Poistettu suosikeista",
    "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
    "You removed {file} from your favorites" : "Poistit tiedoston {file} suosikeista",
    "File changes" : "Tiedostomuutokset",
    "Created by {user}" : "Tekijänä {user}",
    "Changed by {user}" : "Muokkaajana {user}",
    "Deleted by {user}" : "Poistanut {user}",
    "Restored by {user}" : "Palauttanut {user}",
    "Renamed by {user}" : "Uudelleennimennyt {user}",
    "Moved by {user}" : "Siirtänyt {user}",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "You created {file}" : "Loit tiedoston {file}",
    "You created an encrypted file in {file}" : "Loit salatun tiedoston {file}",
    "{user} created {file}" : "{user} loi tiedoston {file}",
    "{user} created an encrypted file in {file}" : "{user} loi salatun tiedoston {file}",
    "{file} was created in a public folder" : "Tiedosto {file} luotiin julkisessa kansiossa",
    "You changed {file}" : "Muutit tiedostoa {file}",
    "You changed an encrypted file in {file}" : "Muutit salattua tiedostoa {file}",
    "{user} changed {file}" : "{user} muutti tiedostoa {file}",
    "{user} changed an encrypted file in {file}" : "{user} muutti salattua tiedostoa {file}",
    "You deleted {file}" : "Poistit tiedoston {file}",
    "You deleted an encrypted file in {file}" : "Poistit salatun tiedoston {file}",
    "{user} deleted {file}" : "{user} poisti tiedoston {file}",
    "{user} deleted an encrypted file in {file}" : "{user} poisti salatun tiedoston {file}",
    "You restored {file}" : "Palautit tiedoston {file}",
    "{user} restored {file}" : "{user} palautti tiedoston {file}",
    "You renamed {oldfile} to {newfile}" : "Uudelleennimesit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile}",
    "You moved {oldfile} to {newfile}" : "Siirsit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} siirsi tiedoston {oldfile} tiedostoksi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong> tai se on <strong>uudelleennimetty</strong>",
    "A new file or folder has been <strong>created</strong>" : "Uusi tiedosto tai kansio on <strong>luotu</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Tiedosto tai kansio on <strong>poistettu</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Rajoita luomis- ja muutosilmoitukset <strong>omiin suosikkitiedostoihin</strong> <em>(Vain listaus)</em>",
    "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
    "Unlimited" : "Rajoittamaton",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "Accept" : "Hyväksy",
    "Reject" : "Hylkää",
    "Incoming ownership transfer from {user}" : "Saapuva omistajuussiirto käyttäjältä {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Hyväksytkö kohteen {path}?\n\nHuomio: Siirtotoimenpiteet hyväksynnän jälkeen saattavat kestää tunnin.",
    "Ownership transfer failed" : "Omistajuuden siirto epäonnistui",
    "Ownership transfer done" : "Omistajuuden siirto valmis",
    "Your ownership transfer of {path} to {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} valmistui.",
    "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
    "File Management" : "Tiedostohallinta",
    "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
    "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Change" : "Muuta",
    "New owner" : "Uusi omistaja",
    "Search users" : "Etsi käyttäjistä",
    "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Transfer" : "Siirrä",
    "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
    "Invalid path selected" : "Valittu virheellinen polku",
    "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
    "Cannot transfer ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
    "Tags" : "Tunnisteet",
    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
    "%s used" : "%s käytetty",
    "%s%% of %s used" : "%s%% / %s käytetty",
    "%1$s of %2$s used" : "%1$s/%2$s käytetty",
    "Settings" : "Asetukset",
    "Show hidden files" : "Näytä piilotetut tiedostot",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Käytä kyseistä osoitetta yhdistääksesi tiedostosi WebDAV kautta",
    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
    "No files in here" : "Täällä ei ole tiedostoja",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Select all" : "Valitse kaikki",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "No favorites yet" : "Ei vielä suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
    "Deleted files" : "Poistetut tiedostot",
    "Shares" : "Jaot",
    "Shared with others" : "Jaettu muille",
    "Shared with you" : "Jaettu kanssasi",
    "Shared by link" : "Jaettu linkillä",
    "Deleted shares" : "Poistetut jaot",
    "Pending shares" : "Odottavat jaot",
    "Text file" : "Tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Käytä tätä osoitetta <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">käyttääksesi tiedostojasi WebDAV:in kautta</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista"
},
"nplurals=2; plural=(n != 1);");
